@@ -1,13 +1,14 @@
 from datetime import datetime
 
-from django.contrib.auth.models import User
 from django.db.models import Count, Q
 
 from mezzanine.blog.forms import BlogPostForm
 from mezzanine.blog.models import BlogPost, BlogCategory
 from mezzanine.generic.models import Keyword
 from mezzanine import template
+from mezzanine.utils.models import get_user_model
 
+User = get_user_model()
 
 register = template.Library()
 
