@@ -118,6 +118,16 @@ register_setting(
     ),
 )
 
+register_setting(
+    name="USE_REVERSION",
+    description=_("If ``True`` and ``django-reversion`` is installed in "
+        "``INSTALLED_APP``, reversion's admin class is injected into all of "
+        "the admin classes that are based upon ``DisplayableAdmin``, "
+        "such as blog admin and all of the page admins."),
+    editable=False,
+    default=False,
+)
+
 register_setting(
     name="FORMS_USE_HTML5",
     description=_("If ``True``, website forms will use HTML5 features."),
@@ -179,6 +189,15 @@ register_setting(
     default=10,
 )
 
+register_setting(
+    name="MEDIA_LIBRARY_PER_SITE",
+    label=_("Media library per site"),
+    description=_("If ``True``, each site will use its own directory within "
+        "the filebrowser media library."),
+    editable=False,
+    default=False,
+)
+
 register_setting(
     name="OWNABLE_MODELS_ALL_EDITABLE",
     description=_("Models that subclass ``Ownable`` and use the "
@@ -462,12 +481,12 @@ register_setting(
     editable=False,
     default=(
         "ACCOUNTS_VERIFICATION_REQUIRED", "ADMIN_MEDIA_PREFIX",
-        "BLOG_BITLY_USER", "BLOG_BITLY_KEY",
+        "BLOG_BITLY_USER", "BLOG_BITLY_KEY", "BLOG_USE_FEATURED_IMAGE",
         "COMMENTS_DISQUS_SHORTNAME", "COMMENTS_NUM_LATEST",
         "COMMENTS_DISQUS_API_PUBLIC_KEY", "COMMENTS_DISQUS_API_SECRET_KEY",
         "DEV_SERVER", "FORMS_USE_HTML5", "GRAPPELLI_INSTALLED",
         "GOOGLE_ANALYTICS_ID", "JQUERY_FILENAME", "LOGIN_URL", "LOGOUT_URL",
-        "PAGES_MENU_SHOW_ALL", "SITE_TITLE", "SITE_TAGLINE", "RATINGS_MAX",
+        "SITE_TITLE", "SITE_TAGLINE", "RATINGS_MAX",
     ),
 )
 
