@@ -1,8 +1,6 @@
-
 from socket import gethostname
 
 from django.conf import settings
-from django.contrib.auth.models import User
 from django.contrib.auth import models as auth_app
 from django.contrib.sites.models import Site
 from django.contrib.sites.management import create_default_site
@@ -11,10 +9,12 @@ from django.core.management import call_command
 from django.db.models.signals import post_syncdb
 
 from mezzanine.pages.models import Page
-
 from mezzanine.pages import models as pages_app
+from mezzanine.utils.models import get_user_model
 from mezzanine.utils.tests import copy_test_to_media
 
+User = get_user_model()
+
 
 def create_user(app, created_models, verbosity, interactive, **kwargs):
     if settings.DEBUG and User in created_models and not interactive:
@@ -30,6 +30,12 @@ def create_user(app, created_models, verbosity, interactive, **kwargs):
 
 
 def create_pages(app, created_models, verbosity, interactive, **kwargs):
+    if not all([
+        'mezzanine.forms' in settings.INSTALLED_APPS,
+        'mezzanine.galleries' in settings.INSTALLED_APPS,
+        'mezzanine.blog' in settings.INSTALLED_APPS]):
+        return
+
     from mezzanine.forms.models import Form
     from mezzanine.galleries.models import Gallery
 
@@ -38,8 +44,8 @@ def create_pages(app, created_models, verbosity, interactive, **kwargs):
         call_command("loaddata", "mezzanine_required.json")
         if interactive:
             confirm = raw_input("\nWould you like to install some initial "
-                                "content?\nEg: About page, Blog, Contact "
-                                "form, Gallery. (yes/no): ")
+                                "demo pages?\nEg: About us, Contact form, "
+                                "Gallery. (yes/no): ")
             while True:
                 if confirm == "yes":
                     break
@@ -53,34 +59,34 @@ def create_site(app, created_models, verbosity, interactive, **kwargs):
     if Site in created_models:
         domain = "127.0.0.1:8000" if settings.DEBUG else gethostname()
         if interactive:
-            entered = raw_input("\nA site record is required. Please enter "
-                                "the domain and optional port in the format "
-                                "'domain:port'. For example 'localhost:8000' "
-                                "or 'www.example.com'. Hit enter to use the "
-                                "default (%s): " % domain)
+            entered = raw_input("\nA site record is required.\nPlease "
+                                "enter the domain and optional port in "
+                                "the format 'domain:port'.\nFor example "
+                                "'localhost:8000' or 'www.example.com'. "
+                                "\nHit enter to use the default (%s): " %
+                                domain)
             if entered:
                 domain = entered.strip("': ")
         if verbosity >= 1:
             print
-            print "Creating default Site %s ... " % domain
+            print "Creating default site record: %s ... " % domain
             print
         Site.objects.create(name="Default", domain=domain)
 
 
 def install_optional_data(verbosity):
+    if verbosity >= 1:
+        print
+        print "Creating demo pages: About us, Contact form, Gallery ..."
+        print
     from mezzanine.galleries.models import Gallery
-
     call_command("loaddata", "mezzanine_optional.json")
     zip_name = "gallery.zip"
     copy_test_to_media("mezzanine.core", zip_name)
     gallery = Gallery.objects.get()
     gallery.zip_import = zip_name
     gallery.save()
-    if verbosity >= 1:
-        print
-        print ("Creating demo content "
-               "(About page, Blog, Contact form, Gallery) ...")
-        print
+
 
 if not settings.TESTING:
     post_syncdb.connect(create_user, sender=auth_app)
