@@ -89,7 +89,7 @@ class BaseGenericRelation(GenericRelation):
         if issubclass(for_model, self.model):
             instance_id = kwargs["instance"].object_pk
             try:
-                instance = self.model.objects.get(id=instance_id)
+                instance = for_model.objects.get(id=instance_id)
             except self.model.DoesNotExist:
                 # Instance itself was deleted - signals are irrelevant.
                 return
@@ -159,7 +159,7 @@ class KeywordsField(BaseGenericRelation):
         isn't a form field mapped to ``GenericRelation`` model fields.
         """
         from mezzanine.generic.forms import KeywordsWidget
-        kwargs["widget"] = KeywordsWidget()
+        kwargs["widget"] = KeywordsWidget
         return super(KeywordsField, self).formfield(**kwargs)
 
     def save_form_data(self, instance, data):
