@@ -2,8 +2,10 @@
 from collections import defaultdict
 
 from django.core.urlresolvers import reverse
+from django.template.defaultfilters import linebreaksbr, urlize
 
 from mezzanine import template
+from mezzanine.conf import settings
 from mezzanine.generic.forms import ThreadedCommentForm
 from mezzanine.generic.models import ThreadedComment
 
@@ -70,3 +72,17 @@ def recent_comments(context):
     comments = ThreadedComment.objects.all().select_related(depth=1)
     context["comments"] = comments.order_by("-id")[:latest]
     return context
+
+
+@register.filter
+def comment_filter(comment_text):
+    """
+    Passed comment text to be rendered through the function defined
+    by the ``COMMENT_FILTER`` setting. If no function is defined
+    (the default), Django's ``linebreaksbr`` and ``urlize`` filters
+    are used.
+    """
+    filter_func = settings.COMMENT_FILTER
+    if not filter_func:
+        filter_func = lambda s: linebreaksbr(urlize(s))
+    return filter_func(comment_text)
