@@ -8,7 +8,7 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 
 from mezzanine.pages.models import Page, RichTextPage, Link
-from mezzanine.core.admin import DisplayableAdmin
+from mezzanine.core.admin import DisplayableAdmin, DisplayableAdminForm
 from mezzanine.utils.urls import admin_url
 
 
@@ -16,6 +16,19 @@ page_fieldsets = deepcopy(DisplayableAdmin.fieldsets)
 page_fieldsets[0][1]["fields"] += ("in_menus", "login_required",)
 
 
+class PageAdminForm(DisplayableAdminForm):
+
+    def clean_slug(self):
+        """
+        If the slug has been changed, save the old one. We will use it later
+        in PageAdmin.model_save() to make the slug change propagate down the
+        page tree.
+        """
+        if self.instance.slug != self.cleaned_data['slug']:
+            self.instance._old_slug = self.instance.slug
+        return self.cleaned_data['slug']
+
+
 class PageAdmin(DisplayableAdmin):
     """
     Admin class for the ``Page`` model and all subclasses of
@@ -23,6 +36,7 @@ class PageAdmin(DisplayableAdmin):
     ``Page`` model and its subclasses.
     """
 
+    form = PageAdminForm
     fieldsets = page_fieldsets
 
     def __init__(self, *args, **kwargs):
@@ -42,18 +56,18 @@ class PageAdmin(DisplayableAdmin):
             # Insert each field between the publishing fields and nav
             # fields. Do so in reverse order to retain the order of
             # the model's fields.
-            for field in reversed(self.model._meta.fields):
-                check_fields = [f.name for f in Page._meta.fields]
-                check_fields.append("page_ptr")
-                try:
-                    check_fields.extend(self.exclude)
-                except (AttributeError, TypeError):
-                    pass
-                try:
-                    check_fields.extend(self.form.Meta.exclude)
-                except (AttributeError, TypeError):
-                    pass
-                if field.name not in check_fields and field.editable:
+            exclude_fields = Page._meta.get_all_field_names() + ["page_ptr"]
+            try:
+                exclude_fields.extend(self.exclude)
+            except (AttributeError, TypeError):
+                pass
+            try:
+                exclude_fields.extend(self.form.Meta.exclude)
+            except (AttributeError, TypeError):
+                pass
+            fields = self.model._meta.fields + self.model._meta.many_to_many
+            for field in reversed(fields):
+                if field.name not in exclude_fields and field.editable:
                     self.fieldsets[0][1]["fields"].insert(3, field.name)
 
     def in_menu(self):
@@ -98,8 +112,9 @@ class PageAdmin(DisplayableAdmin):
                                        content_model.id)
                 return HttpResponseRedirect(change_url)
         extra_context = extra_context or {}
-        extra_context["hide_delete_link"] = not page.can_delete(request)
-        extra_context["hide_slug_field"] = page.overridden()
+        can_delete = content_model.can_delete(request)
+        extra_context["hide_delete_link"] = not can_delete
+        extra_context["hide_slug_field"] = content_model.overridden()
         return super(PageAdmin, self).change_view(request, object_id,
                                                   extra_context=extra_context)
 
@@ -124,8 +139,15 @@ class PageAdmin(DisplayableAdmin):
 
     def save_model(self, request, obj, form, change):
         """
-        Set the ID of the parent page if passed in via querystring.
+        Set the ID of the parent page if passed in via querystring, and make
+        sure the new slug propagates to all descendant pages.
         """
+        if change and hasattr(obj, "_old_slug"):
+            # _old_slug was set in PageAdminForm.clean_slug().
+            new_slug = obj.slug
+            obj.slug = obj._old_slug
+            obj.set_slug(new_slug)
+
         # Force parent to be saved to trigger handling of ordering and slugs.
         parent = request.GET.get("parent")
         if parent is not None and not change:
