@@ -16,6 +16,10 @@ class MenusField(MultiChoiceField):
             default = [t[0] for t in choices]
         elif not default:
             default = None
+        if isinstance(default, (tuple, list)):
+            # Django seeing just a mutable default would force it to unicode.
+            d = tuple(default)
+            default = lambda: d
         defaults = {"max_length": 100, "choices": choices, "default": default}
         defaults.update(kwargs)
         super(MenusField, self).__init__(*args, **defaults)
