@@ -1,4 +1,3 @@
-
 from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.http import HttpResponse
 from django.shortcuts import redirect
@@ -86,7 +85,9 @@ class PageMiddleware(object):
                 return processor_response
             elif processor_response:
                 try:
-                    response.context_data.update(processor_response)
+                    for k in processor_response:
+                        if k not in response.context_data:
+                            response.context_data[k] = processor_response[k]
                 except (TypeError, ValueError):
                     name = "%s.%s" % (processor.__module__, processor.__name__)
                     error = ("The page processor %s returned %s but must "
