@@ -8,6 +8,7 @@ from django.db import models
 from django.utils.html import urlize
 from django.utils.simplejson import loads
 from django.utils.translation import ugettext_lazy as _
+from django.conf import settings
 
 from mezzanine.twitter.managers import TweetManager
 from mezzanine.utils.timezone import make_aware
@@ -85,6 +86,9 @@ class Query(models.Model):
             tweet.text = urlize(tweet_json["text"])
             tweet.text = re_usernames.sub(replace_usernames, tweet.text)
             tweet.text = re_hashtags.sub(replace_hashtags, tweet.text)
+            if getattr(settings, 'TWITTER_STRIP_HIGH_MULTIBYTE', False):
+                chars = [ch for ch in tweet.text if ord(ch) < 0x800]
+                tweet.text = ''.join(chars)
             d = datetime.strptime(tweet_json["created_at"], date_format)
             d -= timedelta(seconds=timezone)
             tweet.created_at = make_aware(d)
